@@ -1,7 +1,7 @@
 package Unix::Passwd::File;
 
-our $DATE = '2015-03-07'; # DATE
-our $VERSION = '0.16'; # VERSION
+our $DATE = '2015-03-10'; # DATE
+our $VERSION = '0.17'; # VERSION
 
 use 5.010001;
 use strict;
@@ -557,7 +557,7 @@ sub list_users {
             }
 
             $stash->{res} = [200, "OK", \@rows];
-            $stash->{res}[3]{result_format_options}{any}{table_column_orders} =
+            $stash->{res}[3]{format_options}{any}{table_column_orders} =
                 [\@passwd_field_names] if $detail;
 
             $stash->{exit}++;
@@ -718,7 +718,7 @@ sub list_groups {
             }
 
             $stash->{res} = [200, "OK", \@rows];
-            $stash->{res}[3]{result_format_options}{any}{table_column_orders} =
+            $stash->{res}[3]{format_options}{any}{table_column_orders} =
                 [\@group_field_names] if $detail;
 
             $stash->{exit}++;
@@ -1939,7 +1939,7 @@ Unix::Passwd::File - Manipulate /etc/{passwd,shadow,group,gshadow} entries
 
 =head1 VERSION
 
-This document describes version 0.16 of Unix::Passwd::File (from Perl distribution Unix-Passwd-File), released on 2015-03-07.
+This document describes version 0.17 of Unix::Passwd::File (from Perl distribution Unix-Passwd-File), released on 2015-03-10.
 
 =head1 SYNOPSIS
 
@@ -2996,7 +2996,7 @@ Please visit the project's homepage at L<https://metacpan.org/release/Unix-Passw
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/sharyanto/perl-Unix-Passwd-File>.
+Source repository is at L<https://github.com/perlancar/perl-Unix-Passwd-File>.
 
 =head1 BUGS
 
